Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/dynamicroles.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/dynamicroles.py	(revision 10222)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/dynamicroles.py	(revision 10226)
@@ -42,5 +42,5 @@
     # role to add in case this role was found
     rolename_mapping = {
-        'waeup.local.ClearanceOfficer':'waeup.ApplicationsOfficer',
+        'waeup.local.ApplicationsManager':'waeup.ApplicationsManager',
         }
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/permissions.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/permissions.py	(revision 10222)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/permissions.py	(revision 10226)
@@ -60,5 +60,10 @@
 class ApplicationsOfficer(grok.Role):
     grok.name('waeup.ApplicationsOfficer')
-    grok.title(u'Applications Officer')
+    grok.title(u'Applications Officer (view only)')
+    grok.permissions('waeup.viewApplication', 'waeup.viewApplicantsTab')
+
+class ApplicationsManager(grok.Role):
+    grok.name('waeup.ApplicationsManager')
+    grok.title(u'Applications Manager')
     grok.permissions('waeup.manageApplication', 'waeup.viewApplication',
                      'waeup.viewApplicantsTab', 'waeup.payApplicant')
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 10222)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_browser.py	(revision 10226)
@@ -297,23 +297,25 @@
         return
 
-    # We have no local roles yet
-    #def test_local_roles_add_delete(self):
-    #    # Managers can assign and delete local roles of applicants root
-    #    myusers = self.app['users']
-    #    myusers.addUser('bob', 'bobssecret')
-    #    self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
-    #    self.browser.open(self.manage_root_path)
-    #    self.browser.getControl(name="user").value = ['bob']
-    #    self.browser.getControl(name="local_role").value = [
-    #        'waeup.local.ApplicationsOfficer']
-    #    self.browser.getControl("Add local role").click()
-    #    self.assertTrue('<td>bob</td>' in self.browser.contents)
-    #    # Remove the role assigned
-    #    ctrl = self.browser.getControl(name='role_id')
-    #    ctrl.getControl(value='bob|waeup.ApplicationsOfficer').selected = True
-    #    self.browser.getControl("Remove selected local roles").click()
-    #    self.assertTrue('Successfully removed:' in self.browser.contents)
-    #    self.assertFalse('<td>bob</td>' in self.browser.contents)
-    #    return
+    def test_local_roles_add_delete(self):
+        # Managers can assign and delete local roles of applicants root
+        myusers = self.app['users']
+        myusers.addUser('bob', 'bobssecret')
+        self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
+        self.browser.open('http://localhost/app/faculties/fac1/dep1/manage')
+        self.browser.getControl(name="user").value = ['bob']
+        self.browser.getControl(name="local_role").value = [
+            'waeup.local.ApplicationsManager']
+        self.browser.getControl("Add local role").click()
+        self.assertTrue('<td>bob</td>' in self.browser.contents)
+        # Remove the role assigned
+        ctrl = self.browser.getControl(name='role_id')
+        ctrl.getControl(
+            value='bob|waeup.local.ApplicationsManager').selected = True
+        self.browser.getControl("Remove selected local roles").click()
+        self.assertTrue(
+            'Local role successfully removed: bob|waeup.local.ApplicationsManager'
+            in self.browser.contents)
+        self.assertFalse('<td>bob</td>' in self.browser.contents)
+        return
 
     def test_add_delete_container(self):
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_dynamicroles.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_dynamicroles.py	(revision 10222)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_dynamicroles.py	(revision 10226)
@@ -47,8 +47,7 @@
         super(ApplicantPrincipalRoleManagerFunctionalTests, self).setUp()
         self.applicant.course1 = self.certificate
-        self.officer_role = 'waeup.ApplicationsOfficer'
-        # assign clearance permissions for a virtual officer
+        # assign application manage permissions for a virtual officer
         prm = IPrincipalRoleManager(self.department)
-        prm.assignRoleToPrincipal('waeup.local.ClearanceOfficer', 'alice')
+        prm.assignRoleToPrincipal('waeup.local.ApplicationsManager', 'alice')
         return
 
@@ -78,8 +77,9 @@
 
     def test_valid_officer(self):
         # for an officer that has clearance role on the connected dept
         # we get the ApplicationsOfficer role on our applicant
         prm = IPrincipalRoleManager(self.applicant)
         result = prm.getRolesForPrincipal('alice')
-        self.assertEqual(result, [('waeup.ApplicationsOfficer', Allow)])
+        self.assertEqual(result, [('waeup.ApplicationsManager', Allow)])
         return
@@ -78,8 +77,9 @@
 
     def test_valid_officer(self):
-        # for an officer that has clearance role on the connected dept
-        # we get the ApplicationsOfficer role on our applicant
+        # for an officer that has application manage permissions
+        # on the connected dept
+        # we get the ApplicationsManager role on our applicant
         prm = IPrincipalRoleManager(self.applicant)
         result = prm.getRolesForPrincipal('alice')
